wot.ot package
==============

Submodules
----------

wot.ot.full\_trajectory module
------------------------------

.. automodule:: wot.ot.full_trajectory
    :members:
    :undoc-members:
    :show-inheritance:

wot.ot.optimal\_transport module
--------------------------------

.. automodule:: wot.ot.optimal_transport
    :members:
    :undoc-members:
    :show-inheritance:

wot.ot.optimal\_transport\_helper module
----------------------------------------

.. automodule:: wot.ot.optimal_transport_helper
    :members:
    :undoc-members:
    :show-inheritance:

wot.ot.trajectory module
------------------------

.. automodule:: wot.ot.trajectory
    :members:
    :undoc-members:
    :show-inheritance:

wot.ot.trajectory\_trends module
--------------------------------

.. automodule:: wot.ot.trajectory_trends
    :members:
    :undoc-members:
    :show-inheritance:

wot.ot.transport\_map\_summary module
-------------------------------------

.. automodule:: wot.ot.transport_map_summary
    :members:
    :undoc-members:
    :show-inheritance:

wot.ot.util module
------------------

.. automodule:: wot.ot.util
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: wot.ot
    :members:
    :undoc-members:
    :show-inheritance:
